@@ -25,7 +25,8 @@
 
 int main( int argc, char ** argv ) {
     QApplication app(argc, argv);
-    app.setWindowIcon(QIcon::fromTheme("mx-user"));
+    app.setWindowIcon(QIcon::fromTheme(app.applicationName()));
+    app.setOrganizationName("MX-Linux");
 
     QTranslator qtTran;
     if (qtTran.load(QLocale::system(), "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
