@@ -1,24 +1,30 @@
-//
-//   Copyright (C) 2003-2010 by Warren Woodford
-//
-//   Licensed under the Apache License, Version 2.0 (the "License");
-//   you may not use this file except in compliance with the License.
-//   You may obtain a copy of the License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the License is distributed on an "AS IS" BASIS,
-//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//   See the License for the specific language governing permissions and
-//   limitations under the License.
-//
+/*
+   Copyright (C) 2003-2010 by Warren Woodford
+   Copyright (C) 2014 by Timothy E. Harris
+   for modifications applicable to the MX Linux project.
+
+   Heavily modified by Adrian adrian@mxlinux.org
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+*/
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include "ui_mainwindow.h"
+#include <QKeyEvent>
 #include <QMessageBox>
+#include <QSettings>
 
 #include "cmd.h"
 
@@ -34,30 +40,34 @@ public:
     // common
     void refresh();
     // special
-    void refreshRestore();
-    void refreshDesktop();
-    void refreshAdd();
-    void refreshDelete();
-    void refreshChangePass();
-    void refreshGroups();
-    void refreshMembership();
-    void refreshRename();
-    void applyRestore();
-    void applyDesktop();
     void applyAdd();
     void applyChangePass();
     void applyDelete();
+    void applyDesktop();
     void applyGroup();
     void applyMembership();
     void applyRename();
+    void applyRestore();
     void buildListGroups();
+    void refreshAdd();
+    void refreshChangePass();
+    void refreshCopy();
+    void refreshDelete();
+    void refreshGroups();
+    void refreshMembership();
+    void refreshRename();
+    void refreshRestore();
     void restartPanel(QString user);
 
 public slots:
     void progress();
     void syncDone(bool success);
 
+protected:
+    void keyPressEvent(QKeyEvent* event);
+
 private slots:
+    void closeApp();
     void on_buttonAbout_clicked();
     void on_buttonApply_clicked();
     void on_buttonCancel_clicked();
@@ -77,8 +87,7 @@ private slots:
     void on_sharedRadioButton_clicked();
     void on_syncRadioButton_clicked();
     void on_tabWidget_currentChanged();
-    void on_toUserComboBox_activated(QString);
-    void on_toUserComboBox_currentIndexChanged(const QString &arg1);
+    void on_toUserComboBox_activated(const QString &arg1);
     void on_userComboBox_activated(QString);
     void on_userComboMembership_activated(QString);
     void on_userNameEdit_textEdited();
@@ -87,6 +96,7 @@ private slots:
 
 private:
     Cmd *shell;
+    QSettings settings;
     QStringList users;
 
 };
